/******************************************************************************
 * FILE:
 *    uc_spc572l64_core_regs_init.S
 *
 * UC:
 *    SPC572L64
 *
 * DESCRIPTION:
 *    Lock-step Core specific registers' initialization.
 *
 * FILE HISTORY:
 *    V1.0    29.01.2018     RO
 *       > Initial version based on crt0_spc58, dedicated to target uC
 *         derivative
 * 
 *	  V2.0    30.01.2018     MF
 *       > file update for SPC572L64
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/


/* ============================================================================
 * SYMBOLS & DEFINES & MACROS
 * ==========================================================================*/

/* Core identification values (PVR.type & PVR.version bitfields)
 * values taken from e200 Cores' manuals */
#define CORE_MAIN_0    0

/* Exported symbols
 * IVOR00 : base address of the Exception table */
.global ls_regs_init
.type ls_regs_init STT_FUNC


/* ============================================================================
 * LOCK-STEP CORE SELECTION
 * Decide which Core register set to initialize, if any, based on CoreId read
 * in the runtime
 * ==========================================================================*/

/* crt0 shared code section */
	.section .crt0, "avx"

ls_regs_init:
	mfspr     r3, 286                   /* read CoreID SFR register */

	e_cmpl16i r3, CORE_MAIN_0
	beq       _z215An3_reg_init

ls_regs_init_end:
	se_blr                              /* return to caller */


/* ============================================================================
 * LOCK-STEP CORE REGISTER INIT
 * Certain Core registers running in Lockstep needs to be initialized by write
 * operation before they are read back, which might cause an Lockstep error,
 * if their value after Power-On is different.
 * ==========================================================================*/

_z215An3_reg_init:
	
	se_blr


